nsim package
============

Subpackages
-----------

.. toctree::

    nsim.analyses1
    nsim.analysesN
    nsim.models

Submodules
----------

nsim.nsim module
----------------

.. automodule:: nsim.nsim
    :members:
    :undoc-members:
    :show-inheritance:

nsim.readfile module
--------------------

.. automodule:: nsim.readfile
    :members:
    :undoc-members:
    :show-inheritance:

nsim.timeseries module
----------------------

.. automodule:: nsim.timeseries
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: nsim
    :members:
    :undoc-members:
    :show-inheritance:
